//region Imports
'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
var gulpif = require('gulp-if');
var through = require('through2');
var changed = require('gulp-changed');
var ignore = require('gulp-ignore');
var gutil = require('gulp-util');
var path = require('path');
var _ = require('lodash');
var babel = require('gulp-babel');
var del = require('del');
//endregion

// Babel logging.
function logFileHelpers() {
  return through.obj(function (file, enc, cb) {
    var src = file.history[0];
    var dest = file.history[1];
    var relPath = function relPath(f) {
      return path.relative('.', f);
    };
    gutil.log('Compiling (Babel):', gutil.colors.red(relPath(src) + ' -> ' + relPath(dest)));
    //gutil.log(file.babel.usedHelpers)
    cb(null, file);
  });
}

exports['default'] = function (gulp, opts) {

  _.defaults(opts, {
    srcGlob: '',
    shouldCompileTests: false,
    destDir: '',
    testsGlob: '',
    babel: {
      stage: 0,
      optional: ['runtime']
    }
  });

  gulp.task('lib:compile', function () {
    return gulp.src(opts.srcGlob).pipe(gulpif(gulp.isWatching, changed(opts.destDir))).pipe(gulpif(!opts.shouldCompileTests, ignore.exclude(opts.testsGlob))).pipe(babel(opts.babel)).pipe(gulp.dest(opts.destDir)).pipe(logFileHelpers());
  });

  gulp.task('lib:clean', function () {
    gutil.log('Cleaning:', gutil.colors.red(opts.destDir));
    return del(opts.destGlob);
  });

  gulp.task('lib:watch', gulp.series('lib:clean', 'lib:compile'), function () {

    // Used by `compile` task to check whether we should only compile changed files.
    gulp.isWatching = true;

    gulp.watch(opts.srcGlob, gulp.series('lib:compile')).on('change', function (evt) {
      gutil.log('---');
      gutil.log('File changed:', gutil.colors.red(evt.path));
    });
  });
};

module.exports = exports['default'];