//region Imports
const gulpif = require('gulp-if')
const through = require('through2')
const changed = require('gulp-changed')
const ignore = require('gulp-ignore')
const gutil = require('gulp-util')
const path = require('path')
const _ = require('lodash')
const babel = require('gulp-babel')
const del = require('del')
//endregion

// Babel logging.
function logFileHelpers() {
  return through.obj(function(file, enc, cb) {
    var src = file.history[0]
    var dest = file.history[1]
    const relPath = (f) => { return path.relative('.', f) }
    gutil.log('Compiling (Babel):', gutil.colors.red(relPath(src) + ' -> ' + relPath(dest)))
    //gutil.log(file.babel.usedHelpers)
    cb(null, file)
  })
}

export default (gulp, opts) => {

  _.defaults(opts, {
    srcGlob: '',
    shouldCompileTests: false,
    destDir: '',
    testsGlob: '',
    babel: {
      stage: 0,
      optional: ['runtime'],
    }
  })

  gulp.task('lib:compile', () => {
    return gulp.src(opts.srcGlob)
      .pipe(gulpif(gulp.isWatching, changed(opts.destDir)))
      .pipe(gulpif(!opts.shouldCompileTests, ignore.exclude(opts.testsGlob)))
      .pipe(babel(opts.babel))
      .pipe(gulp.dest(opts.destDir))
      .pipe(logFileHelpers())
  })

  gulp.task('lib:clean', () => {
    gutil.log('Cleaning:', gutil.colors.red(opts.destDir))
    return del(opts.destGlob)
  })

  gulp.task('lib:watch', gulp.series('lib:clean', 'lib:compile'), function() {

    // Used by `compile` task to check whether we should only compile changed files.
    gulp.isWatching = true

    gulp.watch(opts.srcGlob, gulp.series('lib:compile')).on('change', (evt) => {
      gutil.log('---')
      gutil.log('File changed:', gutil.colors.red(evt.path))
    })

  })

}
